Channel class

Constructors

Channel()

Properties

callbackStream Stream<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
resuResultCallbackStreamController StreamController<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

invoke(MethodChannel methodChannel, dynamic methodName, [dynamic methodArgs]) Future