MethodChannelFlutterResu class

An implementation of FlutterResuPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFlutterResu()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cc() Future<void>
override
cs() Future<void>
override
D(String a) Future<void>
override
E(List<int> d) Future<void>
override
I() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
O(bool uc, bool ua) Future<void>
override
S(String u) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited