FlutterResuPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterResuPlatform
- Implementers
Constructors
- FlutterResuPlatform()
- Constructs a FlutterResuPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cc(
) → Future< void> -
cs(
) → Future< void> -
D(
String a) → Future< void> -
E(
List< int> d) → Future<void> -
I(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
O(
bool uc, bool ua) → Future< void> -
S(
String u) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterResuPlatform
-
The default instance of FlutterResuPlatform to use.
getter/setter pair